function [ec,r,theta]=trace_complexe_locale(z,h,n,fun,dfun,trgr,trca,varargin)


% Etude de la dforme locale de la fonction F de C dans C
%
% *********************************************************
%  [ec,r,theta]=trace_complexe_locale(z,h,n,fun,dfun,trgr,trca,varargin) : 
%      calcule l'cart entre la dformation du carr de sommets d'affixes
%      z-h/2-ih/2,z+h/2-ih/2,z+h/2+ih/2,z-h/2+ih/2
%      par la fonction F et sa linaris.
%      si trgr=1, trac des dformations.
%      
%  * Variables d'entres 
%     * z : complexe
%     * h : rel strictement positif
%     * n : nombre de points pour le calcul de la dforme
%     * fun : fonction donne
%     * dfun : sa drive (peut tre vide, auquel cas, elle est calcule en 
%              symbolique)
%  * Variables d'entres optionnelles 
%     * trgr : entier gal  1 (trac des carrs)  ou 0 (pas de trac)
%              gal  1 par dfaut
%     * trca : entier gal  1 (trac du carr initial)  ou 0 (pas de trac)
%              gal  1 par dfaut
%     * varargin :  arguments optionnels de la fonction F
 %  * Variables de sortie :
%     *  ec :  cart entre les dformes du carrs de sommets d'affixes
%              z-h/2-ih/2,z+h/2-ih/2,z+h/2+ih/2,z-h/2+ih/2
%              par la fonction F et sa linarise.
%     * r, theta : module et arguements (en degr dans ]-180,180]) de F'(z)
% 
%   EXEMPLES :
%       [ec,r,theta]=trace_complexe_locale(1+i,1e-0,100,inline('exp(z)'),inline('exp(z)'))
%       [ec,r,theta]=trace_complexe_locale(1+i,1e-1,100,inline('exp(z)'),inline('exp(z)'))
%       [ec,r,theta]=trace_complexe_locale(1+i,1e-4,100,inline('exp(z)'),inline('exp(z)'))
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune 
%
% *********************************************************
%
% 2013 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

nin=nargin;
if nin<=4
    testdf=1;
else
    testdf=isempty(dfun);
end
if nin<=5
    trgr=1;
else
    if isempty(trgr)
        trgr=1;
    end
end
if nin<=6
    trca=1;
else
    if isempty(trca)
        trca=1;
    end
end
if testdf
    syms x;
    g=diff(feval(fun,x,varargin{:}),x);
    nb=length(varargin);
    % Amliorer cela TROP LENT dans le cas vardf=0
    if nb==0
        dfun=inline(char(g));
        vardf=1;
    else
        vardf=0;
    end
else
    vardf=1;
end
T=linspace(0,h,n);
s1=z-h/2-i*h/2;
s2=z+h/2-i*h/2;
s3=z+h/2+i*h/2;
s4=z-h/2+i*h/2;
Z=[s1+T,s2+i*T,s3-T,s4-i*T];
Zb=z-i*h/2+i*T;
Zc=z-h/2+T;
fz=feval(fun,z,varargin{:});
FZ=feval(fun,Z,varargin{:});
FZb=feval(fun,Zb,varargin{:});
FZc=feval(fun,Zc,varargin{:});
% Amliorer cela TROP LENT dans le cas vardf=0
if vardf
    x=z;
    dfz=feval(dfun,x,varargin{:});
else
    x=z;
    dfx=g;
    if ~(isnumeric(dfx));
        dfz=eval(dfx);
    end
end
FZlin=fz+(Z-z)*dfz;
FZlinb=fz+(Zb-z)*dfz;
FZlinc=fz+(Zc-z)*dfz;
dudu=[FZ-FZlin,FZb-FZlinb,FZc-FZlinc];
if ~(isnumeric(dudu))
    dudu=eval(dudu);
end
ec=max(abs(dudu));
theta=angle(dfz)/pi*180;
r=abs(dfz);
if trgr
    clf;
    hold on;
    axis equal;
    if trca
        plot([Z-z,Zb-z]+fz,'g');
    end
    plot(real(FZ),imag(FZ),'b');
    plot(real(FZlin),imag(FZlin),'r');
    if trca
        legend('Carr initial','Dformation exacte','Dformation linarise',1);
    else
        legend('Exacte','Linarise',1);
    end
    if trca
        plot(real(Zc-z+fz),imag(Zc-z+fz),'g');
    end
    plot(real(FZb),imag(FZb),'b');
    plot(real(FZc),imag(FZc),'b');
    plot(real(FZlinb),imag(FZlinb),'r');
    plot(real(FZlinc),imag(FZlinc),'r');
    hold off;
end
