function trace_potentiel_complexe(xmin,xmax,hx,ymin,ymax,hy,ni,fun,test,trpl,varargin)

% trac des lignes et des quipotentiels 
%
% *********************************************************
%  trace_potentiel_complexe(xmin,xmax,hx,ymin,ymax,hy,ni,fun,test,trpl,varargin) :
%
%  * Variables d'entres
%     * xmin,xmax : valeurs mini et maxi des abscisses 
%     * hx : pas en x
%     * ymin,ymax : valeurs mini et maxi des ordonnes
%     * hy : pas en y
%     * ni: nombre d'isovaleurs
%     * fun : fonction donne
%  * Variables d'entres optionnelles
%     * test : fonction de (x,y) qui est nulle sur l'ventuelle rgion du
%              plan  enlever
%     * trpl : entier gal  1 (trac du potentiel en couleur) 
%                            0 (pas trac du potentiel en couleur, mais les
%                            quipotentielles sont en couleur)
%              gal  1 par dfaut
%     * varargin :  arguments optionnels de la fonction F
%
%   EXEMPLES :
%       a) 
%           trace_potentiel_complexe(-2,2,0.005,-2,2,0.005,30,inline('a*z','z','a'),[],[],exp(i*pi/4));
%       b) 
%           fun=inline('log(z)');
%           Ymax=0.0001;
%           Rmax=0.01;
%           test=@(X,Y,Ymax,Rmax)((abs(Y)<=Ymax&X<0)|(sqrt(X.^2+Y.^2)<=Rmax));
%           trace_potentiel_complexe(-2,2,0.005,-2,2,0.005,30,fun,@(X,Y)test(X,Y,Ymax,Rmax));
%        c) 
%           Ymax=0.0001;
%           Rmax=0.01;
%           test=@(X,Y,Ymax,Rmax)((abs(Y)<=Ymax&X<0)|(sqrt(X.^2+Y.^2)<=Rmax));
%           fun=inline('log(z)+a*z','z','a');
%           a=.4;
%           trace_potentiel_complexe(-2,2,0.005,-2,2,0.005,30,fun,@(X,Y)test(X,Y,Ymax,Rmax),1,a);
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune
%
% *********************************************************
%
% 2013 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

nin=nargin;
if nin<=9
    trpl=1;
else
    if isempty(trpl)
        trpl=1;
    end
end
x=xmin:hx:xmax;
y=ymin:hy:ymax;
[X,Y]=meshgrid(x,y);
dudutest=0;
if nargin>=9
    if ~isempty(test)
        dudutest=1;
        dudu=feval(test,X,Y);
    end
end
if dudutest
    X(dudu)=NaN;
    Y(dudu)=NaN;
end
Z=feval(fun,X+i*Y,varargin{:});
clf;
hold on;
if trpl
    pcolor(X,Y,real(Z));
    shading interp;
    contour(X,Y,real(Z),ni,':k');
    contour(X,Y,imag(Z),ni,'k');
    axis equal;
else
    contour(X,Y,real(Z),ni);
    contour(X,Y,imag(Z),ni,'k');
    axis equal;
end
hold off;