function [x,xp]=val_equa_diff_impul(tt,a,b,epsi,sigmap)

% Valeur de la solution de l'quation diffrentiel avec impulsion en zro
%
% *********************************************************
%  [x,xp]=val_equa_diff_impul(tt,a,b,epsi,sigmap) : 
%      Valeur de la solution de l'quation diffrentiel avec impulsion en
%      zro
%         a) si epsi=0
%              x''+a*x+b*x'=0  x(0)=0','x'(0)=sigmap
%         b) si epsi>0
%              x''+a*x+b*x'=g
%              o g(t)=0            sur R\[-epsi/2,epspi/2]
%                     =sigmap/epsi  sur [-epsi/2,epspi/2]
%              x nulle sur ]-infty,-epsi/2]
% La fonction a t crite en copiant-collant le rsulat de
% resol_sym_equa_diff_impul.m
%
%      
%  * Variables d'entres 
%     * tt : tableau quelconque des instants t
%     * a,b,epsi>=0,sigmap : paramtre de l'quation diffrentielle.
%
%  * Variables de sortie :
%     *  x,xp :  valeurs et drives  de la solution en tt
%
%
% ************ Fonctions auxiliaires utilises ************
%
%    aucune 
%
% *********************************************************
%
% 2013 by          Jrme BASTIEN
%                  Universit Claude Bernard Lyon I, UFRSTAPS, Laboratoire CRIS, Villeurbanne
%                  E-Mail : jerome.bastien@univ-lyon1.fr

x=zeros(size(tt));
xp=zeros(size(tt));
if b^2-4*a~=0
    if epsi==0
        indd=find(tt>0);
        if sum(indd)>0
            t=tt(indd);
            x(indd)=real(-(b.^2-4.*a).^(1./2)./(-b.^2+4.*a).*sigmap.*exp((-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*t)+(b.^2-4.*a).^(1./2)./(-b.^2+4.*a).*sigmap.*exp((-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*t));
            xp(indd)=real(-(b.^2-4.*a).^(1./2)./(-b.^2+4.*a).*sigmap.*(-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*exp((-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*t)+(b.^2-4.*a).^(1./2)./(-b.^2+4.*a).*sigmap.*(-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*exp((-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*t));
        end
    else
        indd=find((tt>-epsi/2)&(tt<=epsi/2));
        if sum(indd)>0
            t=tt(indd);
            x(indd)=real(-1./2.*exp((-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*t).*(-(b.^2-4.*a).^(1./2).*b-b.^2+4.*a).*sigmap./epsi./(-b.^2+4.*a)./exp(-1./2.*(-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*epsi)./a-1./2.*exp((-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*t).*sigmap./epsi.*(-b.^2+(b.^2-4.*a).^(1./2).*b+4.*a)./(-b.^2+4.*a)./a./exp(-1./2.*(-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*epsi)+1./a.*sigmap./epsi);
            xp(indd)=real(-1./2.*(-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*exp((-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*t).*(-(b.^2-4.*a).^(1./2).*b-b.^2+4.*a).*sigmap./epsi./(-b.^2+4.*a)./exp(-1./2.*(-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*epsi)./a-1./2.*(-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*exp((-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*t).*sigmap./epsi.*(-b.^2+(b.^2-4.*a).^(1./2).*b+4.*a)./(-b.^2+4.*a)./a./exp(-1./2.*(-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*epsi));
        end
        indd=find(tt>epsi/2);
        if sum(indd)>0
            t=tt(indd);
            x(indd)=real(1./2.*(-(b.^2-4.*a).^(1./2).*b-b.^2+4.*a).*(exp(1./4.*(b-(b.^2-4.*a).^(1./2)).*epsi)-exp(-1./4.*(b-(b.^2-4.*a).^(1./2)).*epsi)).*sigmap./exp(1./4.*(b-(b.^2-4.*a).^(1./2)).*epsi)./epsi./exp(1./2.*(-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*epsi)./a./(-b.^2+4.*a).*exp((-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*t)-1./2.*(exp(-1./4.*(b+(b.^2-4.*a).^(1./2)).*epsi)-exp(1./4.*(b+(b.^2-4.*a).^(1./2)).*epsi)).*sigmap.*(-b.^2+(b.^2-4.*a).^(1./2).*b+4.*a)./exp(1./4.*(b+(b.^2-4.*a).^(1./2)).*epsi)./epsi./exp(1./2.*(-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*epsi)./a./(-b.^2+4.*a).*exp((-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*t));
            xp(indd)=real(1./2.*(-(b.^2-4.*a).^(1./2).*b-b.^2+4.*a).*(exp(1./4.*(b-(b.^2-4.*a).^(1./2)).*epsi)-exp(-1./4.*(b-(b.^2-4.*a).^(1./2)).*epsi)).*sigmap./exp(1./4.*(b-(b.^2-4.*a).^(1./2)).*epsi)./epsi./exp(1./2.*(-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*epsi)./a./(-b.^2+4.*a).*(-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*exp((-1./2.*b+1./2.*(b.^2-4.*a).^(1./2)).*t)-1./2.*(exp(-1./4.*(b+(b.^2-4.*a).^(1./2)).*epsi)-exp(1./4.*(b+(b.^2-4.*a).^(1./2)).*epsi)).*sigmap.*(-b.^2+(b.^2-4.*a).^(1./2).*b+4.*a)./exp(1./4.*(b+(b.^2-4.*a).^(1./2)).*epsi)./epsi./exp(1./2.*(-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*epsi)./a./(-b.^2+4.*a).*(-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*exp((-1./2.*b-1./2.*(b.^2-4.*a).^(1./2)).*t));
        end
    end
else
    if epsi==0
        indd=find(tt>0);
        if sum(indd)>0
            t=tt(indd);
            x(indd)=sigmap.*exp(-1./2.*t.*b).*t;
            xp(indd)=-1./2.*sigmap.*b.*exp(-1./2.*t.*b).*t+sigmap.*exp(-1./2.*t.*b);
        end
    else
        indd=find((tt>-epsi/2)&(tt<=epsi/2));
        if sum(indd)>0
            t=tt(indd);
            x(indd)=-1./b.^2.*(epsi.*b+4)./exp(1./4.*epsi.*b).*sigmap./epsi.*exp(-1./2.*t.*b)-2.*exp(-1./2.*t.*b).*t./exp(1./4.*epsi.*b)./b.*sigmap./epsi+4./b.^2.*sigmap./epsi;
            xp(indd)=1./2./b.*(epsi.*b+4)./exp(1./4.*epsi.*b).*sigmap./epsi.*exp(-1./2.*t.*b)+exp(-1./2.*t.*b).*t./exp(1./4.*epsi.*b).*sigmap./epsi-2.*exp(-1./2.*t.*b)./exp(1./4.*epsi.*b)./b.*sigmap./epsi;
        end
        indd=find(tt>epsi/2);
        if sum(indd)>0
            t=tt(indd);
            x(indd)=-sigmap./exp(1./4.*epsi.*b).*(exp(-1./4.*epsi.*b).*b.*epsi+b.*exp(1./4.*epsi.*b).*epsi+4.*exp(-1./4.*epsi.*b)-4.*exp(1./4.*epsi.*b))./b.^2./exp(-1./4.*epsi.*b)./epsi.*exp(-1./2.*t.*b)-2.*sigmap.*(exp(-1./4.*epsi.*b)-exp(1./4.*epsi.*b))./exp(-1./4.*epsi.*b)./b./epsi./exp(1./4.*epsi.*b).*exp(-1./2.*t.*b).*t;
            xp(indd)=1./2.*sigmap./exp(1./4.*epsi.*b).*(exp(-1./4.*epsi.*b).*b.*epsi+b.*exp(1./4.*epsi.*b).*epsi+4.*exp(-1./4.*epsi.*b)-4.*exp(1./4.*epsi.*b))./b./exp(-1./4.*epsi.*b)./epsi.*exp(-1./2.*t.*b)+sigmap.*(exp(-1./4.*epsi.*b)-exp(1./4.*epsi.*b))./exp(-1./4.*epsi.*b)./epsi./exp(1./4.*epsi.*b).*exp(-1./2.*t.*b).*t-2.*sigmap.*(exp(-1./4.*epsi.*b)-exp(1./4.*epsi.*b))./exp(-1./4.*epsi.*b)./b./epsi./exp(1./4.*epsi.*b).*exp(-1./2.*t.*b);
        end
    end
end





